# trashpanda

**trashpanda** is a collection of helper methods composing tasks around
pandas.DataFrames and Series. Either they are to specific (or I didn't found
them).

![trashpanda icon](https://trashpanda.readthedocs.io/en/latest/_images/trashpanda-icon.svg "A trash panda")

## Installing

Installing the latest release using pip is recommended.

````shell script
$ pip install trashpanda
````

## Usage

The api reference with all available methods can be found at 
https://trashpanda.readthedocs.io/en/latest/


## Authors

* **David Scheliga** 
    [@gitlab](https://gitlab.com/david.scheliga)
    [@Linkedin](https://www.linkedin.com/in/david-scheliga-576984171/)
    - Initial work
    - Maintainer

## License

This project is licensed under the GNU GENERAL PUBLIC LICENSE - see the
[LICENSE](https://gitlab.com/david.scheliga/dicthandling/blob/master/LICENSE) file for details

## Acknowledge

- [Code style: black](https://github.com/psf/black)
- [PurpleBooth](https://gist.github.com/PurpleBooth/109311bb0361f32d87a2)
- [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
